@@ -2,11 +2,12 @@ package Log::Log4perl::Appender::TAP;
 
 use strict;
 use warnings;
-use Test::Builder::Module;
+use 5.008001;
+use Test2::API qw( context );
 our @ISA = qw( Log::Log4perl::Appender );
 
 # ABSTRACT: Append to TAP output
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 
 sub new
@@ -15,19 +16,18 @@ sub new
   my $class = ref $proto || $proto;
   my %args = @_;
   bless {
-    builder => Test::Builder::Module->builder,
     method  => $args{method} || 'note',
   }, $class;
 }
 
-sub _builder { shift->{builder} }
-
 sub log
 {
   my $self = shift;
   my %args = @_;
   my $method = $self->{method};
-  $self->_builder->$method($args{message});
+  my $ctx = context();
+  $ctx->$method($args{message});
+  $ctx->release;
   return;
 }
 
@@ -37,13 +37,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Log::Log4perl::Appender::TAP - Append to TAP output
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -55,7 +57,7 @@ version 0.02
  log4perl.appender.TAP=Log::Log4perl::Appender::TAP
  log4perl.appender.TAP.method=diag
  log4perl.appender.TAP=layout=PatternLayout
- log4perl.appender.TAP=layout.ConversionPattern="[%rms] %m%n
+ log4perl.appender.TAP=layout.ConversionPattern="[%rms] %m%n"
  CONF
  
  DEBUG "this message doesn't see the light of day";
